aboutsummaryrefslogtreecommitdiffstats
path: root/src/gen/java/io
diff options
context:
space:
mode:
Diffstat (limited to 'src/gen/java/io')
-rw-r--r--src/gen/java/io/swagger/api/ApiException.java27
-rw-r--r--src/gen/java/io/swagger/api/ApiOriginFilter.java27
-rw-r--r--src/gen/java/io/swagger/api/ApiResponseMessage.java27
-rw-r--r--src/gen/java/io/swagger/api/DcaeServiceTypesApi.java118
-rw-r--r--src/gen/java/io/swagger/api/DcaeServiceTypesApiService.java39
-rw-r--r--src/gen/java/io/swagger/api/DcaeServicesApi.java44
-rw-r--r--src/gen/java/io/swagger/api/DcaeServicesApiService.java29
-rw-r--r--src/gen/java/io/swagger/api/DcaeServicesGroupbyApi.java27
-rw-r--r--src/gen/java/io/swagger/api/DcaeServicesGroupbyApiService.java27
-rw-r--r--src/gen/java/io/swagger/api/JacksonJsonProvider.java27
-rw-r--r--src/gen/java/io/swagger/api/NotFoundException.java27
-rw-r--r--src/gen/java/io/swagger/api/StringUtil.java27
-rw-r--r--src/gen/java/io/swagger/model/DCAEService.java31
-rw-r--r--src/gen/java/io/swagger/model/DCAEServiceComponent.java27
-rw-r--r--src/gen/java/io/swagger/model/DCAEServiceComponentRequest.java27
-rw-r--r--src/gen/java/io/swagger/model/DCAEServiceGroupByResults.java27
-rw-r--r--src/gen/java/io/swagger/model/DCAEServiceGroupByResultsPropertyValues.java27
-rw-r--r--src/gen/java/io/swagger/model/DCAEServiceRequest.java51
-rw-r--r--src/gen/java/io/swagger/model/DCAEServiceType.java294
-rw-r--r--src/gen/java/io/swagger/model/DCAEServiceTypeRequest.java342
-rw-r--r--src/gen/java/io/swagger/model/InlineResponse200.java27
-rw-r--r--src/gen/java/io/swagger/model/InlineResponse2001.java27
-rw-r--r--src/gen/java/io/swagger/model/InlineResponse200Links.java27
-rw-r--r--src/gen/java/io/swagger/model/Link.java27
24 files changed, 673 insertions, 707 deletions
diff --git a/src/gen/java/io/swagger/api/ApiException.java b/src/gen/java/io/swagger/api/ApiException.java
index a2be1d8..cdc6162 100644
--- a/src/gen/java/io/swagger/api/ApiException.java
+++ b/src/gen/java/io/swagger/api/ApiException.java
@@ -1,28 +1,25 @@
-package io.swagger.api;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.api;
+
@javax.annotation.Generated(value = "class io.swagger.codegen.languages.JavaJerseyServerCodegen", date = "2016-04-18T20:16:22.119Z")
public class ApiException extends Exception{
private int code;
diff --git a/src/gen/java/io/swagger/api/ApiOriginFilter.java b/src/gen/java/io/swagger/api/ApiOriginFilter.java
index b449d84..b6f29f2 100644
--- a/src/gen/java/io/swagger/api/ApiOriginFilter.java
+++ b/src/gen/java/io/swagger/api/ApiOriginFilter.java
@@ -1,28 +1,25 @@
-package io.swagger.api;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.api;
+
import java.io.IOException;
import javax.servlet.*;
diff --git a/src/gen/java/io/swagger/api/ApiResponseMessage.java b/src/gen/java/io/swagger/api/ApiResponseMessage.java
index 018a208..bf4e13a 100644
--- a/src/gen/java/io/swagger/api/ApiResponseMessage.java
+++ b/src/gen/java/io/swagger/api/ApiResponseMessage.java
@@ -1,28 +1,25 @@
-package io.swagger.api;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.api;
+
import javax.xml.bind.annotation.XmlTransient;
@javax.xml.bind.annotation.XmlRootElement
diff --git a/src/gen/java/io/swagger/api/DcaeServiceTypesApi.java b/src/gen/java/io/swagger/api/DcaeServiceTypesApi.java
index f8604b8..72f1f63 100644
--- a/src/gen/java/io/swagger/api/DcaeServiceTypesApi.java
+++ b/src/gen/java/io/swagger/api/DcaeServiceTypesApi.java
@@ -1,28 +1,25 @@
-package io.swagger.api;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.api;
+
import io.swagger.api.factories.DcaeServiceTypesApiServiceFactory;
import io.swagger.annotations.ApiParam;
@@ -46,13 +43,36 @@ public class DcaeServiceTypesApi {
@Context
UriInfo uriInfo;
- public static Link buildLinkForGet(UriInfo uriInfo, String rel, String vnfType, Integer offset) {
+ public static Link buildLinkForGet(UriInfo uriInfo, String rel, String typeName, Boolean onlyLatest, Boolean onlyActive,
+ String vnfType, String serviceId, String serviceLocation, String asdcServiceId,
+ String asdcResourceId, Integer offset) {
UriBuilder ub = uriInfo.getBaseUriBuilder().path(DcaeServiceTypesApi.class)
.path(DcaeServiceTypesApi.class, "dcaeServiceTypesGet");
+ if (typeName != null) {
+ ub.queryParam("typeName", typeName);
+ }
+ if (onlyLatest != null) {
+ ub.queryParam("onlyLatest", onlyLatest);
+ }
+ if (onlyActive != null) {
+ ub.queryParam("onlyActive", onlyActive);
+ }
if (vnfType != null) {
ub.queryParam("vnfType", vnfType);
}
+ if (serviceId != null) {
+ ub.queryParam("serviceId", serviceId);
+ }
+ if (serviceLocation != null) {
+ ub.queryParam("serviceLocation", serviceLocation);
+ }
+ if (asdcServiceId != null) {
+ ub.queryParam("asdcServiceId", asdcServiceId);
+ }
+ if (asdcResourceId != null) {
+ ub.queryParam("asdcResourceId", asdcResourceId);
+ }
if (offset != null) {
ub.queryParam("offset", offset);
}
@@ -70,44 +90,57 @@ public class DcaeServiceTypesApi {
@io.swagger.annotations.ApiResponses(value = {
@io.swagger.annotations.ApiResponse(code = 200, message = "List of `DCAEServiceType` objects", response = InlineResponse200.class)})
public Response dcaeServiceTypesGet(
- @ApiParam(value = "") @QueryParam("vnfType") String vnfType,
- @ApiParam(value = "") @QueryParam("serviceId") String serviceId,
- @ApiParam(value = "") @QueryParam("serviceLocation") String serviceLocation,
+ @ApiParam(value = "Filter by service type name") @QueryParam("typeName") String typeName,
+ @ApiParam(value = "If set to true, query returns just the latest versions of DCAE service types. If set to false, then all versions are returned. Default is true")
+ @DefaultValue("true") @QueryParam("onlyLatest") Boolean onlyLatest,
+ @ApiParam(value = "If set to true, query returns only *active* DCAE service types. If set to false, then all DCAE service types are returned. Default is true")
+ @DefaultValue("true") @QueryParam("onlyActive") Boolean onlyActive,
+ @ApiParam(value = "Filter by associated vnf type. No wildcards, matches are explicit. This field is treated case insensitive.")
+ @QueryParam("vnfType") String vnfType,
+ @ApiParam(value = "Filter by assocaited service id. Instances with service id null or empty is always returned.")
+ @QueryParam("serviceId") String serviceId,
+ @ApiParam(value = "Filter by associated service location. Instances with service location null or empty is always returned.")
+ @QueryParam("serviceLocation") String serviceLocation,
+ @ApiParam(value = "Filter by associated asdc design service id. Setting this to `NONE` will return instances that have asdc service id set to null")
+ @QueryParam("asdcServiceId") String asdcServiceId,
+ @ApiParam(value = "Filter by associated asdc design resource id. Setting this to `NONE` will return instances that have asdc resource id set to null")
+ @QueryParam("asdcResourceId") String asdcResourceId,
@ApiParam(value = "Query resultset offset used for pagination (zero-based)") @QueryParam("offset") Integer offset,
@Context SecurityContext securityContext)
throws NotFoundException {
- return delegate.dcaeServiceTypesGet(vnfType, serviceId, serviceLocation, offset, uriInfo, securityContext);
+ return delegate.dcaeServiceTypesGet(typeName, onlyLatest, onlyActive, vnfType, serviceId, serviceLocation,
+ asdcServiceId, asdcResourceId, offset, uriInfo, securityContext);
}
- public static Link buildLinkForGet(UriInfo uriInfo, String rel, String typeName) {
+ public static Link buildLinkForGet(UriInfo uriInfo, String rel, String typeId) {
// This same method can be used for PUTs as well
UriBuilder ub = uriInfo.getBaseUriBuilder().path(DcaeServiceTypesApi.class)
- .path(DcaeServiceTypesApi.class, "dcaeServiceTypesTypeNameGet");
- Link.Builder lb = Link.fromUri(ub.build(typeName));
+ .path(DcaeServiceTypesApi.class, "dcaeServiceTypesTypeIdGet");
+ Link.Builder lb = Link.fromUri(ub.build(typeId));
lb.rel(rel);
return lb.build();
}
@GET
- @Path("/{typeName}")
- @Consumes({"application/json", "application/vnd.dcae.inventory.v1+json"})
- @Produces({"application/json", "application/vnd.dcae.inventory.v1+json"})
+ @Path("/{typeId}")
+ @Consumes({"application/json"})
+ @Produces({"application/json"})
@io.swagger.annotations.ApiOperation(value = "", notes = "Get a `DCAEServiceType` object.", response = DCAEServiceType.class, tags = {})
@io.swagger.annotations.ApiResponses(value = {
@io.swagger.annotations.ApiResponse(code = 200, message = "Single `DCAEServiceType` object", response = DCAEServiceType.class),
@io.swagger.annotations.ApiResponse(code = 404, message = "Resource not found", response = DCAEServiceType.class)})
- public Response dcaeServiceTypesTypeNameGet(
- @ApiParam(value = "", required = true) @PathParam("typeName") String typeName,
+ public Response dcaeServiceTypesTypeIdGet(
+ @ApiParam(value = "", required = true) @PathParam("typeId") String typeId,
@Context SecurityContext securityContext)
throws NotFoundException {
- return delegate.dcaeServiceTypesTypeNameGet(typeName, uriInfo, securityContext);
+ return delegate.dcaeServiceTypesTypeIdGet(typeId, uriInfo, securityContext);
}
- @PUT
- @Path("/{typeName}")
- @Consumes({"application/json", "application/vnd.dcae.inventory.v1+json"})
- @Produces({"application/json", "application/vnd.dcae.inventory.v1+json"})
+ @POST
+ @Path("/")
+ @Consumes({"application/json"})
+ @Produces({"application/json"})
@io.swagger.annotations.ApiOperation(value = "", notes = "Inserts a new `DCAEServiceType` or updates an existing instance. Updates are only allowed iff there are no running DCAE services of the requested type,",
response = DCAEServiceType.class, tags = {})
@io.swagger.annotations.ApiResponses(value = {
@@ -115,10 +148,25 @@ public class DcaeServiceTypesApi {
@io.swagger.annotations.ApiResponse(code = 400, message = "Bad request provided.", response = ApiResponseMessage.class),
@io.swagger.annotations.ApiResponse(code = 409, message = "Failed to update because there are still DCAE services of the requested type running.", response = ApiResponseMessage.class)})
public Response dcaeServiceTypesTypeNamePut(
- @ApiParam(value = "", required = true) @PathParam("typeName") String typeName,
@ApiParam(value = "", required = true) @Valid DCAEServiceTypeRequest request,
@Context SecurityContext securityContext)
throws NotFoundException {
- return delegate.dcaeServiceTypesTypeNamePut(typeName, request, uriInfo, securityContext);
+ return delegate.dcaeServiceTypesTypeIdPost(request, uriInfo, securityContext);
}
+
+ @DELETE
+ @Path("/{typeId}")
+ @io.swagger.annotations.ApiOperation(value = "", notes = "Deactivates existing `DCAEServiceType` instances", response = DCAEServiceType.class, tags = {})
+ @io.swagger.annotations.ApiResponses(value = {
+ @io.swagger.annotations.ApiResponse(code = 200, message = "`DCAEServiceType` has been deactivated", response = ApiResponseMessage.class),
+ @io.swagger.annotations.ApiResponse(code = 404, message = "`DCAEServiceType` not found", response = ApiResponseMessage.class),
+ @io.swagger.annotations.ApiResponse(code = 410, message = "`DCAEServiceType` already gone", response = ApiResponseMessage.class)
+ })
+ public Response dcaeServiceTypesTypeIdDelete(
+ @ApiParam(value = "", required = true) @PathParam("typeId") String typeId,
+ @Context SecurityContext securityContext)
+ throws NotFoundException {
+ return delegate.dcaeServiceTypesTypeIdDelete(typeId, uriInfo, securityContext);
+ }
+
}
diff --git a/src/gen/java/io/swagger/api/DcaeServiceTypesApiService.java b/src/gen/java/io/swagger/api/DcaeServiceTypesApiService.java
index 60fee9c..afc7476 100644
--- a/src/gen/java/io/swagger/api/DcaeServiceTypesApiService.java
+++ b/src/gen/java/io/swagger/api/DcaeServiceTypesApiService.java
@@ -1,28 +1,25 @@
-package io.swagger.api;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.api;
+
import io.swagger.model.DCAEServiceTypeRequest;
import javax.ws.rs.core.Response;
@@ -31,12 +28,16 @@ import javax.ws.rs.core.UriInfo;
@javax.annotation.Generated(value = "class io.swagger.codegen.languages.JavaJerseyServerCodegen", date = "2016-04-18T20:16:22.119Z")
public abstract class DcaeServiceTypesApiService {
- public abstract Response dcaeServiceTypesGet(String vnfType, String serviceId, String serviceLocation, Integer offset,
- UriInfo uriInfo, SecurityContext securityContext)
+ public abstract Response dcaeServiceTypesGet(String typeName, Boolean onlyLatest, Boolean onlyActive,
+ String vnfType, String serviceId, String serviceLocation,
+ String asdcServiceId, String asdcResourceId,
+ Integer offset, UriInfo uriInfo, SecurityContext securityContext)
throws NotFoundException;
- public abstract Response dcaeServiceTypesTypeNameGet(String typeName, UriInfo uriInfo, SecurityContext securityContext)
+ public abstract Response dcaeServiceTypesTypeIdGet(String typeId, UriInfo uriInfo, SecurityContext securityContext)
throws NotFoundException;
- public abstract Response dcaeServiceTypesTypeNamePut(String typeName, DCAEServiceTypeRequest request, UriInfo uriInfo,
+ public abstract Response dcaeServiceTypesTypeIdPost(DCAEServiceTypeRequest request, UriInfo uriInfo,
SecurityContext securityContext)
throws NotFoundException;
+ public abstract Response dcaeServiceTypesTypeIdDelete(String typeId, UriInfo uriInfo, SecurityContext securityContext)
+ throws NotFoundException;
}
diff --git a/src/gen/java/io/swagger/api/DcaeServicesApi.java b/src/gen/java/io/swagger/api/DcaeServicesApi.java
index 81715d4..55d79f3 100644
--- a/src/gen/java/io/swagger/api/DcaeServicesApi.java
+++ b/src/gen/java/io/swagger/api/DcaeServicesApi.java
@@ -1,28 +1,25 @@
-package io.swagger.api;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.api;
+
import io.dropwizard.jersey.params.DateTimeParam;
import io.swagger.api.factories.DcaeServicesApiServiceFactory;
@@ -48,8 +45,8 @@ public class DcaeServicesApi {
@Context
UriInfo uriInfo;
- public static Link buildLinkForGetByTypeName(UriInfo uriInfo, String rel, String typeName) {
- return buildLinkForGet(uriInfo, rel, typeName, null, null, null, null, null, null, null);
+ public static Link buildLinkForGetByTypeId(UriInfo uriInfo, String rel, String typeId) {
+ return buildLinkForGet(uriInfo, rel, typeId, null, null, null, null, null, null, null);
}
public static Link buildLinkForGetByVnfType(UriInfo uriInfo, String rel, String vnfType) {
@@ -60,14 +57,14 @@ public class DcaeServicesApi {
return buildLinkForGet(uriInfo, rel, null, null, null, vnfLocation, null, null, null, null);
}
- public static Link buildLinkForGet(UriInfo uriInfo, String rel, String typeName, String vnfId, String vnfType,
+ public static Link buildLinkForGet(UriInfo uriInfo, String rel, String typeId, String vnfId, String vnfType,
String vnfLocation, String componentType, Boolean shareable, DateTime created,
Integer offset) {
UriBuilder ub = uriInfo.getBaseUriBuilder().path(DcaeServicesApi.class)
.path(DcaeServicesApi.class, "dcaeServicesGet");
- if (typeName != null) {
- ub.queryParam("typeName", typeName);
+ if (typeId != null) {
+ ub.queryParam("typeId", typeId);
}
if (vnfId != null) {
ub.queryParam("vnfId", vnfId);
@@ -106,9 +103,10 @@ public class DcaeServicesApi {
@io.swagger.annotations.ApiResponse(code = 502, message = "Bad response from DCAE controller", response = ApiResponseMessage.class),
@io.swagger.annotations.ApiResponse(code = 504, message = "Failed to connect with DCAE controller", response = ApiResponseMessage.class)})
public Response dcaeServicesGet(
- @ApiParam(value = "DCAE service type name") @QueryParam("typeName") String typeName,
+ @ApiParam(value = "DCAE service type name") @QueryParam("typeId") String typeId,
@ApiParam(value = "") @QueryParam("vnfId") String vnfId,
- @ApiParam(value = "") @QueryParam("vnfType") String vnfType,
+ @ApiParam(value = "Filter by associated vnf type. This field is treated case insensitive.")
+ @QueryParam("vnfType") String vnfType,
@ApiParam(value = "") @QueryParam("vnfLocation") String vnfLocation,
@ApiParam(value = "Use to filter by a specific DCAE service component type") @QueryParam("componentType") String componentType,
@ApiParam(value = "Use to filter by DCAE services that have shareable components or not") @QueryParam("shareable") Boolean shareable,
@@ -116,7 +114,7 @@ public class DcaeServicesApi {
@ApiParam(value = "Query resultset offset used for pagination (zero-based)") @QueryParam("offset") Integer offset,
@Context SecurityContext securityContext)
throws NotFoundException {
- return delegate.dcaeServicesGet(typeName, vnfId, vnfType, vnfLocation, componentType, shareable,
+ return delegate.dcaeServicesGet(typeId, vnfId, vnfType, vnfLocation, componentType, shareable,
(created == null ? null : created.get()), offset, uriInfo, securityContext);
}
diff --git a/src/gen/java/io/swagger/api/DcaeServicesApiService.java b/src/gen/java/io/swagger/api/DcaeServicesApiService.java
index 4b4aa38..99f9f25 100644
--- a/src/gen/java/io/swagger/api/DcaeServicesApiService.java
+++ b/src/gen/java/io/swagger/api/DcaeServicesApiService.java
@@ -1,28 +1,25 @@
-package io.swagger.api;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.api;
+
import io.swagger.model.DCAEServiceRequest;
import org.joda.time.DateTime;
@@ -32,7 +29,7 @@ import javax.ws.rs.core.UriInfo;
@javax.annotation.Generated(value = "class io.swagger.codegen.languages.JavaJerseyServerCodegen", date = "2016-04-18T20:16:22.119Z")
public abstract class DcaeServicesApiService {
- public abstract Response dcaeServicesGet(String typeName, String vnfId, String vnfType, String vnfLocation,
+ public abstract Response dcaeServicesGet(String typeId, String vnfId, String vnfType, String vnfLocation,
String componentType, Boolean shareable, DateTime created, Integer offset,
UriInfo uriInfo, SecurityContext securityContext)
throws NotFoundException;
diff --git a/src/gen/java/io/swagger/api/DcaeServicesGroupbyApi.java b/src/gen/java/io/swagger/api/DcaeServicesGroupbyApi.java
index db0ab69..d108e31 100644
--- a/src/gen/java/io/swagger/api/DcaeServicesGroupbyApi.java
+++ b/src/gen/java/io/swagger/api/DcaeServicesGroupbyApi.java
@@ -1,28 +1,25 @@
-package io.swagger.api;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.api;
+
import io.swagger.api.factories.DcaeServicesGroupbyApiServiceFactory;
import io.swagger.annotations.ApiParam;
diff --git a/src/gen/java/io/swagger/api/DcaeServicesGroupbyApiService.java b/src/gen/java/io/swagger/api/DcaeServicesGroupbyApiService.java
index d842c46..bc25d4e 100644
--- a/src/gen/java/io/swagger/api/DcaeServicesGroupbyApiService.java
+++ b/src/gen/java/io/swagger/api/DcaeServicesGroupbyApiService.java
@@ -1,28 +1,25 @@
-package io.swagger.api;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.api;
+
import javax.ws.rs.core.Response;
import javax.ws.rs.core.SecurityContext;
import javax.ws.rs.core.UriInfo;
diff --git a/src/gen/java/io/swagger/api/JacksonJsonProvider.java b/src/gen/java/io/swagger/api/JacksonJsonProvider.java
index 2e1affb..c7a5db2 100644
--- a/src/gen/java/io/swagger/api/JacksonJsonProvider.java
+++ b/src/gen/java/io/swagger/api/JacksonJsonProvider.java
@@ -1,28 +1,25 @@
-package io.swagger.api;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.api;
+
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.jaxrs.json.JacksonJaxbJsonProvider;
import io.swagger.util.Json;
diff --git a/src/gen/java/io/swagger/api/NotFoundException.java b/src/gen/java/io/swagger/api/NotFoundException.java
index f3bde83..3eb483f 100644
--- a/src/gen/java/io/swagger/api/NotFoundException.java
+++ b/src/gen/java/io/swagger/api/NotFoundException.java
@@ -1,28 +1,25 @@
-package io.swagger.api;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.api;
+
@javax.annotation.Generated(value = "class io.swagger.codegen.languages.JavaJerseyServerCodegen", date = "2016-04-18T20:16:22.119Z")
public class NotFoundException extends ApiException {
private int code;
diff --git a/src/gen/java/io/swagger/api/StringUtil.java b/src/gen/java/io/swagger/api/StringUtil.java
index 04cb0e4..e20f46f 100644
--- a/src/gen/java/io/swagger/api/StringUtil.java
+++ b/src/gen/java/io/swagger/api/StringUtil.java
@@ -1,28 +1,25 @@
-package io.swagger.api;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.api;
+
@javax.annotation.Generated(value = "class io.swagger.codegen.languages.JavaJerseyServerCodegen", date = "2016-04-18T20:16:22.119Z")
public class StringUtil {
/**
diff --git a/src/gen/java/io/swagger/model/DCAEServiceComponent.java b/src/gen/java/io/swagger/model/DCAEServiceComponent.java
index 34c81a8..6550c76 100644
--- a/src/gen/java/io/swagger/model/DCAEServiceComponent.java
+++ b/src/gen/java/io/swagger/model/DCAEServiceComponent.java
@@ -1,28 +1,25 @@
-package io.swagger.model;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.model;
+
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModelProperty;
diff --git a/src/gen/java/io/swagger/model/DCAEServiceComponentRequest.java b/src/gen/java/io/swagger/model/DCAEServiceComponentRequest.java
index 1f0913f..f65bf38 100644
--- a/src/gen/java/io/swagger/model/DCAEServiceComponentRequest.java
+++ b/src/gen/java/io/swagger/model/DCAEServiceComponentRequest.java
@@ -1,28 +1,25 @@
-package io.swagger.model;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.model;
+
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModel;
diff --git a/src/gen/java/io/swagger/model/DCAEServiceGroupByResults.java b/src/gen/java/io/swagger/model/DCAEServiceGroupByResults.java
index b9f0d34..f8f0449 100644
--- a/src/gen/java/io/swagger/model/DCAEServiceGroupByResults.java
+++ b/src/gen/java/io/swagger/model/DCAEServiceGroupByResults.java
@@ -1,28 +1,25 @@
-package io.swagger.model;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.model;
+
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModel;
diff --git a/src/gen/java/io/swagger/model/DCAEServiceGroupByResultsPropertyValues.java b/src/gen/java/io/swagger/model/DCAEServiceGroupByResultsPropertyValues.java
index 76d69a0..0d39b51 100644
--- a/src/gen/java/io/swagger/model/DCAEServiceGroupByResultsPropertyValues.java
+++ b/src/gen/java/io/swagger/model/DCAEServiceGroupByResultsPropertyValues.java
@@ -1,28 +1,25 @@
-package io.swagger.model;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.model;
+
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModel;
diff --git a/src/gen/java/io/swagger/model/DCAEServiceRequest.java b/src/gen/java/io/swagger/model/DCAEServiceRequest.java
index f9f9083..06f6935 100644
--- a/src/gen/java/io/swagger/model/DCAEServiceRequest.java
+++ b/src/gen/java/io/swagger/model/DCAEServiceRequest.java
@@ -1,28 +1,25 @@
-package io.swagger.model;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.model;
+
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModelProperty;
@@ -40,7 +37,7 @@ import java.util.List;
public class DCAEServiceRequest {
@NotEmpty
- private String typeName = null;
+ private String typeId = null;
@NotEmpty
private String vnfId = null;
@NotEmpty
@@ -54,19 +51,19 @@ public class DCAEServiceRequest {
/**
**/
- public DCAEServiceRequest typeName(String typeName) {
- this.typeName = typeName;
+ public DCAEServiceRequest typeId(String typeId) {
+ this.typeId = typeId;
return this;
}
- @ApiModelProperty(required = true, value = "Name of the associated DCAE service type")
- @JsonProperty("typeName")
- public String getTypeName() {
- return typeName;
+ @ApiModelProperty(required = true, value = "Id of the associated DCAE service type")
+ @JsonProperty("typeId")
+ public String getTypeId() {
+ return typeId;
}
- public void setTypeName(String typeName) {
- this.typeName = typeName;
+ public void setTypeId(String typeId) {
+ this.typeId = typeId;
}
/**
@@ -165,7 +162,7 @@ public class DCAEServiceRequest {
return false;
}
DCAEServiceRequest dCAEServiceRequest = (DCAEServiceRequest) o;
- return Objects.equals(typeName, dCAEServiceRequest.typeName) &&
+ return Objects.equals(typeId, dCAEServiceRequest.typeId) &&
Objects.equals(vnfId, dCAEServiceRequest.vnfId) &&
Objects.equals(vnfType, dCAEServiceRequest.vnfType) &&
Objects.equals(vnfLocation, dCAEServiceRequest.vnfLocation) &&
@@ -175,7 +172,7 @@ public class DCAEServiceRequest {
@Override
public int hashCode() {
- return Objects.hash(typeName, vnfId, vnfType, vnfLocation, deploymentRef, components);
+ return Objects.hash(typeId, vnfId, vnfType, vnfLocation, deploymentRef, components);
}
@Override
@@ -183,7 +180,7 @@ public class DCAEServiceRequest {
StringBuilder sb = new StringBuilder();
sb.append("class DCAEServiceRequest {\n");
- sb.append(" typeName: ").append(toIndentedString(typeName)).append("\n");
+ sb.append(" typeId: ").append(toIndentedString(typeId)).append("\n");
sb.append(" vnfId: ").append(toIndentedString(vnfId)).append("\n");
sb.append(" vnfType: ").append(toIndentedString(vnfType)).append("\n");
sb.append(" vnfLocation: ").append(toIndentedString(vnfLocation)).append("\n");
diff --git a/src/gen/java/io/swagger/model/DCAEServiceType.java b/src/gen/java/io/swagger/model/DCAEServiceType.java
index abe5930..5598604 100644
--- a/src/gen/java/io/swagger/model/DCAEServiceType.java
+++ b/src/gen/java/io/swagger/model/DCAEServiceType.java
@@ -1,222 +1,134 @@
-package io.swagger.model;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.model;
+
import java.util.Objects;
+
import com.fasterxml.jackson.annotation.JsonProperty;
-import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
+import org.hibernate.validator.constraints.NotEmpty;
+
import javax.ws.rs.core.Link;
-import java.util.ArrayList;
import java.util.Date;
-import java.util.List;
+@javax.annotation.Generated(value = "class io.swagger.codegen.languages.JavaJerseyServerCodegen", date = "2016-04-18T20:16:22.119Z")
+public final class DCAEServiceType extends DCAEServiceTypeRequest {
+ @NotEmpty
+ private String typeId = null;
+ @NotEmpty
+ private Link selfLink = null;
+ @NotEmpty
+ private Date created = null;
+ private Date deactivated = null;
-@javax.annotation.Generated(value = "class io.swagger.codegen.languages.JavaJerseyServerCodegen", date = "2016-04-18T20:16:22.119Z")
-public class DCAEServiceType {
-
- private String typeName = null;
- private Link selfLink = null;
- private Date created = null;
- private String owner = null;
- private List<String> vnfTypes = new ArrayList<String>();
- private List<String> serviceIds = null;
- private List<String> serviceLocations = null;
- private String blueprintTemplate = null;
-
- /**
- **/
- public DCAEServiceType typeName(String typeName) {
- this.typeName = typeName;
- return this;
- }
-
-
- @ApiModelProperty(required = true, value = "Unique name for this DCAE service type")
- @JsonProperty("typeName")
- public String getTypeName() {
- return typeName;
- }
- public void setTypeName(String typeName) {
- this.typeName = typeName;
- }
-
- /**
- * Link.title is typeName
- **/
- public DCAEServiceType selfLink(Link selfLink) {
- this.selfLink = selfLink;
- return this;
- }
-
-
- @ApiModelProperty(value = "Link.title is typeName")
- @JsonProperty("selfLink")
- public Link getSelfLink() {
- return selfLink;
- }
- public void setSelfLink(Link selfLink) {
- this.selfLink = selfLink;
- }
-
- /**
- **/
- public DCAEServiceType created(Date created) {
- this.created = created;
- return this;
- }
-
-
- @ApiModelProperty(required = true, value = "Created timestamp for this DCAE service type in epoch time")
- @JsonProperty("created")
- public Date getCreated() {
- return created;
- }
- public void setCreated(Date created) {
- this.created = created;
- }
-
- /**
- **/
- public DCAEServiceType owner(String owner) {
- this.owner = owner;
- return this;
- }
-
-
- @ApiModelProperty(required = true, value = "Name of the owner of this DCAE service type")
- @JsonProperty("owner")
- public String getOwner() {
- return owner;
- }
- public void setOwner(String owner) {
- this.owner = owner;
- }
-
- /**
- **/
- public DCAEServiceType vnfTypes(List<String> vnfTypes) {
- this.vnfTypes = vnfTypes;
- return this;
- }
-
-
- @ApiModelProperty(required = true, value = "List of VNF types associated with this DCAE service type")
- @JsonProperty("vnfTypes")
- public List<String> getVnfTypes() {
- return vnfTypes;
- }
- public void setVnfTypes(List<String> vnfTypes) {
- this.vnfTypes = vnfTypes;
- }
-
- @ApiModelProperty(required = false, value = "List of service ids that are associated with this DCAE service type")
- @JsonProperty("serviceIds")
- public List<String> getServiceIds() {
- return serviceIds;
+ @ApiModelProperty(required = true, value = "Unique identifier for this DCAE service type")
+ @JsonProperty("typeId")
+ public String getTypeId() {
+ return typeId;
}
- public void setServiceIds(List<String> serviceIds) {
- this.serviceIds = serviceIds;
+
+ public void setTypeId(String typeId) {
+ this.typeId = typeId;
}
- @ApiModelProperty(required = false, value = "List of service locations that are associated with this DCAE service type")
- @JsonProperty("serviceLocations")
- public List<String> getServiceLocations() {
- return serviceLocations;
+
+ @ApiModelProperty(required = true, value = "Link to self where the Link.title is typeName")
+ @JsonProperty("selfLink")
+ public Link getSelfLink() {
+ return selfLink;
}
- public void setServiceLocations(List<String> serviceLocations) {
- this.serviceLocations = serviceLocations;
+
+ public void setSelfLink(Link selfLink) {
+ this.selfLink = selfLink;
}
- /**
- * String representation of a Cloudify blueprint with unbound variables
- **/
- public DCAEServiceType blueprintTemplate(String blueprintTemplate) {
- this.blueprintTemplate = blueprintTemplate;
- return this;
- }
-
-
- @ApiModelProperty(required = true, value = "String representation of a Cloudify blueprint with unbound variables")
- @JsonProperty("blueprintTemplate")
- public String getBlueprintTemplate() {
- return blueprintTemplate;
- }
- public void setBlueprintTemplate(String blueprintTemplate) {
- this.blueprintTemplate = blueprintTemplate;
- }
-
-
- @Override
- public boolean equals(Object o) {
- if (this == o) {
- return true;
+
+ @ApiModelProperty(required = true, value = "Created timestamp for this DCAE service type in epoch time")
+ @JsonProperty("created")
+ public Date getCreated() {
+ return created;
}
- if (o == null || getClass() != o.getClass()) {
- return false;
+
+ public void setCreated(Date created) {
+ this.created = created;
}
- DCAEServiceType dCAEServiceType = (DCAEServiceType) o;
- return Objects.equals(typeName, dCAEServiceType.typeName) &&
- Objects.equals(selfLink, dCAEServiceType.selfLink) &&
- Objects.equals(created, dCAEServiceType.created) &&
- Objects.equals(owner, dCAEServiceType.owner) &&
- Objects.equals(vnfTypes, dCAEServiceType.vnfTypes) &&
- Objects.equals(blueprintTemplate, dCAEServiceType.blueprintTemplate);
- }
-
- @Override
- public int hashCode() {
- return Objects.hash(typeName, selfLink, created, owner, vnfTypes, blueprintTemplate);
- }
-
- @Override
- public String toString() {
- StringBuilder sb = new StringBuilder();
- sb.append("class DCAEServiceType {\n");
-
- sb.append(" typeName: ").append(toIndentedString(typeName)).append("\n");
- sb.append(" selfLink: ").append(toIndentedString(selfLink)).append("\n");
- sb.append(" created: ").append(toIndentedString(created)).append("\n");
- sb.append(" owner: ").append(toIndentedString(owner)).append("\n");
- sb.append(" vnfTypes: ").append(toIndentedString(vnfTypes)).append("\n");
- sb.append(" blueprintTemplate: ").append(toIndentedString(blueprintTemplate)).append("\n");
- sb.append("}");
- return sb.toString();
- }
-
- /**
- * Convert the given object to string with each line indented by 4 spaces
- * (except the first line).
- */
- private String toIndentedString(Object o) {
- if (o == null) {
- return "null";
+
+
+ @ApiModelProperty(required = false, value = "Deactivated timestamp for this DCAE service type in epoch time")
+ @JsonProperty("deactivated")
+ public Date getDeactivated() {
+ return deactivated;
+ }
+
+ public void setDeactivated(Date deactivated) {
+ this.deactivated = deactivated;
+ }
+
+ @Override
+ public boolean equals(Object o) {
+ if (this == o) {
+ return true;
+ }
+ if (o == null || getClass() != o.getClass()) {
+ return false;
+ }
+ DCAEServiceType dCAEServiceType = (DCAEServiceType) o;
+ return Objects.equals(typeId, dCAEServiceType.typeId) &&
+ Objects.equals(selfLink, dCAEServiceType.selfLink) &&
+ Objects.equals(created, dCAEServiceType.created) &&
+ Objects.equals(deactivated, dCAEServiceType.deactivated) &&
+ super.equals((DCAEServiceTypeRequest) o);
+ }
+
+ @Override
+ public int hashCode() {
+ return Objects.hash(typeId, selfLink, created, deactivated) + super.hashCode();
+ }
+
+ @Override
+ public String toString() {
+ StringBuilder sb = new StringBuilder();
+ sb.append("class DCAEServiceType {\n");
+
+ sb.append(" typeId: ").append(toIndentedString(typeId)).append("\n");
+ sb.append(" selfLink: ").append(toIndentedString(selfLink)).append("\n");
+ sb.append(" created: ").append(toIndentedString(created)).append("\n");
+ sb.append(" deactivated: ").append(toIndentedString(deactivated)).append("\n");
+ sb.append(super.toString()).append("\n");
+ sb.append("}");
+ return sb.toString();
+ }
+
+ /**
+ * Convert the given object to string with each line indented by 4 spaces
+ * (except the first line).
+ */
+ private String toIndentedString(Object o) {
+ if (o == null) {
+ return "null";
+ }
+ return o.toString().replace("\n", "\n ");
}
- return o.toString().replace("\n", "\n ");
- }
}
diff --git a/src/gen/java/io/swagger/model/DCAEServiceTypeRequest.java b/src/gen/java/io/swagger/model/DCAEServiceTypeRequest.java
index 3e94c24..7cd3577 100644
--- a/src/gen/java/io/swagger/model/DCAEServiceTypeRequest.java
+++ b/src/gen/java/io/swagger/model/DCAEServiceTypeRequest.java
@@ -1,163 +1,227 @@
-package io.swagger.model;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.model;
+
import java.util.Objects;
+
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModelProperty;
import org.hibernate.validator.constraints.NotEmpty;
+import javax.validation.constraints.NotNull;
import java.util.ArrayList;
import java.util.List;
+@javax.annotation.Generated(value = "class io.swagger.codegen.languages.JavaJerseyServerCodegen", date = "2016-04-18T20:16:22.119Z")
+public class DCAEServiceTypeRequest {
+
+ @NotEmpty
+ private String owner = null;
+ @NotEmpty
+ private String typeName = null;
+ @NotNull
+ private Integer typeVersion = 1;
+ @NotEmpty
+ private String blueprintTemplate = null;
+
+ // REVIEW: Look to deprecate these depending upon how the ASDC integration goes
+ private List<String> serviceIds = null;
+ private List<String> vnfTypes = new ArrayList<String>();
+
+ private List<String> serviceLocations = null;
+
+ // TODO: This should eventually become required fields
+ private String asdcServiceId = null;
+ private String asdcResourceId = null;
+ private String asdcServiceURL = null;
+
+
+ /**
+ **/
+ public DCAEServiceTypeRequest owner(String owner) {
+ this.owner = owner;
+ return this;
+ }
+
+
+ @ApiModelProperty(required = true, value = "")
+ @JsonProperty("owner")
+ public String getOwner() {
+ return owner;
+ }
+ public void setOwner(String owner) {
+ this.owner = owner;
+ }
-@javax.annotation.Generated(value = "class io.swagger.codegen.languages.JavaJerseyServerCodegen", date = "2016-04-18T20:16:22.119Z")
-public class DCAEServiceTypeRequest {
-
- @NotEmpty
- private String owner = null;
- @NotEmpty
- private List<String> vnfTypes = new ArrayList<String>();
- @NotEmpty
- private String blueprintTemplate = null;
- private List<String> serviceLocations = null;
- private List<String> serviceIds = null;
-
- /**
- **/
- public DCAEServiceTypeRequest owner(String owner) {
- this.owner = owner;
- return this;
- }
-
-
- @ApiModelProperty(required = true, value = "")
- @JsonProperty("owner")
- public String getOwner() {
- return owner;
- }
- public void setOwner(String owner) {
- this.owner = owner;
- }
-
- /**
- **/
- public DCAEServiceTypeRequest vnfTypes(List<String> vnfTypes) {
- this.vnfTypes = vnfTypes;
- return this;
- }
-
-
- @ApiModelProperty(required = true, value = "")
- @JsonProperty("vnfTypes")
- public List<String> getVnfTypes() {
- return vnfTypes;
- }
- public void setVnfTypes(List<String> vnfTypes) {
- this.vnfTypes = vnfTypes;
- }
-
- /**
- * String representation of a Cloudify blueprint with unbound variables
- **/
- public DCAEServiceTypeRequest blueprintTemplate(String blueprintTemplate) {
- this.blueprintTemplate = blueprintTemplate;
- return this;
- }
-
-
- @ApiModelProperty(required = true, value = "String representation of a Cloudify blueprint with unbound variables")
- @JsonProperty("blueprintTemplate")
- public String getBlueprintTemplate() {
- return blueprintTemplate;
- }
- public void setBlueprintTemplate(String blueprintTemplate) {
- this.blueprintTemplate = blueprintTemplate;
- }
-
- @ApiModelProperty(required = false, value = "List of service locations that are used to associate with DCAE service type. DCAE service types with this propery as null or empty means them apply for every service location.")
- @JsonProperty("serviceLocations")
- public List<String> getServiceLocations() {
- return this.serviceLocations;
- }
- public void setServiceLocations(List<String> serviceLocations) {
- this.serviceLocations = serviceLocations;
- }
-
- @ApiModelProperty(required = false, value = "List of service ids that are used to associate with DCAE service type. DCAE service types with this propery as null or empty means them apply for every service id.")
- @JsonProperty("serviceIds")
- public List<String> getServiceIds() {
- return this.serviceIds;
- }
- public void setServiceIds(List<String> serviceIds) {
- this.serviceIds = serviceIds;
- }
-
-
- @Override
- public boolean equals(Object o) {
- if (this == o) {
- return true;
- }
- if (o == null || getClass() != o.getClass()) {
- return false;
- }
- DCAEServiceTypeRequest dCAEServiceTypeRequest = (DCAEServiceTypeRequest) o;
- return Objects.equals(owner, dCAEServiceTypeRequest.owner) &&
- Objects.equals(vnfTypes, dCAEServiceTypeRequest.vnfTypes) &&
- Objects.equals(blueprintTemplate, dCAEServiceTypeRequest.blueprintTemplate);
- }
-
- @Override
- public int hashCode() {
- return Objects.hash(owner, vnfTypes, blueprintTemplate);
- }
-
- @Override
- public String toString() {
- StringBuilder sb = new StringBuilder();
- sb.append("class DCAEServiceTypeRequest {\n");
-
- sb.append(" owner: ").append(toIndentedString(owner)).append("\n");
- sb.append(" vnfTypes: ").append(toIndentedString(vnfTypes)).append("\n");
- sb.append(" blueprintTemplate: ").append(toIndentedString(blueprintTemplate)).append("\n");
- sb.append("}");
- return sb.toString();
- }
-
- /**
- * Convert the given object to string with each line indented by 4 spaces
- * (except the first line).
- */
- private String toIndentedString(Object o) {
- if (o == null) {
- return "null";
- }
- return o.toString().replace("\n", "\n ");
- }
+ @ApiModelProperty(required = true, value = "Descriptive name for this DCAE service type")
+ @JsonProperty("typeName")
+ public String getTypeName() {
+ return typeName;
+ }
+
+ public void setTypeName(String typeName) {
+ this.typeName = typeName;
+ }
+
+
+ @ApiModelProperty(required = true, value = "Version number for this DCAE service type")
+ @JsonProperty("typeVersion")
+ public Integer getTypeVersion() {
+ return this.typeVersion;
+ }
+
+ public void setTypeVersion(Integer typeVersion) {
+ this.typeVersion = typeVersion;
+ }
+
+ /**
+ **/
+ public DCAEServiceTypeRequest vnfTypes(List<String> vnfTypes) {
+ this.vnfTypes = vnfTypes;
+ return this;
+ }
+
+
+ @ApiModelProperty(required = false, value = "")
+ @JsonProperty("vnfTypes")
+ public List<String> getVnfTypes() {
+ return vnfTypes;
+ }
+
+ public void setVnfTypes(List<String> vnfTypes) {
+ this.vnfTypes = vnfTypes;
+ }
+
+ /**
+ * String representation of a Cloudify blueprint with unbound variables
+ **/
+ public DCAEServiceTypeRequest blueprintTemplate(String blueprintTemplate) {
+ this.blueprintTemplate = blueprintTemplate;
+ return this;
+ }
+
+
+ @ApiModelProperty(required = true, value = "String representation of a Cloudify blueprint with unbound variables")
+ @JsonProperty("blueprintTemplate")
+ public String getBlueprintTemplate() {
+ return blueprintTemplate;
+ }
+
+ public void setBlueprintTemplate(String blueprintTemplate) {
+ this.blueprintTemplate = blueprintTemplate;
+ }
+
+ @ApiModelProperty(required = false, value = "List of service locations that are used to associate with DCAE service type. DCAE service types with this propery as null or empty means them apply for every service location.")
+ @JsonProperty("serviceLocations")
+ public List<String> getServiceLocations() {
+ return this.serviceLocations;
+ }
+
+ public void setServiceLocations(List<String> serviceLocations) {
+ this.serviceLocations = serviceLocations;
+ }
+
+ @ApiModelProperty(required = false, value = "List of service ids that are used to associate with DCAE service type. DCAE service types with this propery as null or empty means them apply for every service id.")
+ @JsonProperty("serviceIds")
+ public List<String> getServiceIds() {
+ return this.serviceIds;
+ }
+
+ public void setServiceIds(List<String> serviceIds) {
+ this.serviceIds = serviceIds;
+ }
+
+ @ApiModelProperty(required = false, value = "Id of service this DCAE service type is associated with. Value source is from ASDC's notification event's field `serviceInvariantUUID`.")
+ @JsonProperty("asdcServiceId")
+ public String getAsdcServiceId() {
+ return asdcServiceId;
+ }
+
+ public void setAsdcServiceId(String asdcServiceId) {
+ this.asdcServiceId = asdcServiceId;
+ }
+
+ @ApiModelProperty(required = false, value = "Id of vf/vnf instance this DCAE service type is associated with. Value source is from ASDC's notification event's field `resourceInvariantUUID`.")
+ @JsonProperty("asdcResourceId")
+ public String getAsdcResourceId() {
+ return asdcResourceId;
+ }
+
+ public void setAsdcResourceId(String asdcResourceId) {
+ this.asdcResourceId = asdcResourceId;
+ }
+
+ @ApiModelProperty(required = false, value = "URL to the ASDC service model")
+ @JsonProperty("asdcServiceURL")
+ public String getAsdcServiceURL() {
+ return asdcServiceURL;
+ }
+
+ public void setAsdcServiceURL(String asdcServiceURL) {
+ this.asdcServiceURL = asdcServiceURL;
+ }
+
+ @Override
+ public boolean equals(Object o) {
+ if (this == o) {
+ return true;
+ }
+ if (o == null || getClass() != o.getClass()) {
+ return false;
+ }
+ DCAEServiceTypeRequest dCAEServiceTypeRequest = (DCAEServiceTypeRequest) o;
+ return Objects.equals(owner, dCAEServiceTypeRequest.owner) &&
+ Objects.equals(vnfTypes, dCAEServiceTypeRequest.vnfTypes) &&
+ Objects.equals(blueprintTemplate, dCAEServiceTypeRequest.blueprintTemplate);
+ }
+
+ @Override
+ public int hashCode() {
+ return Objects.hash(owner, vnfTypes, blueprintTemplate);
+ }
+
+ @Override
+ public String toString() {
+ StringBuilder sb = new StringBuilder();
+ sb.append("class DCAEServiceTypeRequest {\n");
+
+ sb.append(" owner: ").append(toIndentedString(owner)).append("\n");
+ sb.append(" vnfTypes: ").append(toIndentedString(vnfTypes)).append("\n");
+ sb.append(" blueprintTemplate: ").append(toIndentedString(blueprintTemplate)).append("\n");
+ sb.append("}");
+ return sb.toString();
+ }
+
+ /**
+ * Convert the given object to string with each line indented by 4 spaces
+ * (except the first line).
+ */
+ private String toIndentedString(Object o) {
+ if (o == null) {
+ return "null";
+ }
+ return o.toString().replace("\n", "\n ");
+ }
}
diff --git a/src/gen/java/io/swagger/model/InlineResponse200.java b/src/gen/java/io/swagger/model/InlineResponse200.java
index c5ffdf8..0c44fdf 100644
--- a/src/gen/java/io/swagger/model/InlineResponse200.java
+++ b/src/gen/java/io/swagger/model/InlineResponse200.java
@@ -1,28 +1,25 @@
-package io.swagger.model;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.model;
+
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModel;
diff --git a/src/gen/java/io/swagger/model/InlineResponse2001.java b/src/gen/java/io/swagger/model/InlineResponse2001.java
index 26cf3be..88e3816 100644
--- a/src/gen/java/io/swagger/model/InlineResponse2001.java
+++ b/src/gen/java/io/swagger/model/InlineResponse2001.java
@@ -1,28 +1,25 @@
-package io.swagger.model;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.model;
+
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModel;
diff --git a/src/gen/java/io/swagger/model/InlineResponse200Links.java b/src/gen/java/io/swagger/model/InlineResponse200Links.java
index ffcb51a..bff7254 100644
--- a/src/gen/java/io/swagger/model/InlineResponse200Links.java
+++ b/src/gen/java/io/swagger/model/InlineResponse200Links.java
@@ -1,28 +1,25 @@
-package io.swagger.model;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.model;
+
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModel;
diff --git a/src/gen/java/io/swagger/model/Link.java b/src/gen/java/io/swagger/model/Link.java
index 56a6f95..3c69b26 100644
--- a/src/gen/java/io/swagger/model/Link.java
+++ b/src/gen/java/io/swagger/model/Link.java
@@ -1,28 +1,25 @@
-package io.swagger.model;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.model;
+
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModel;
diff --git a/src/gen/java/io/swagger/model/DCAEService.java b/src/gen/java/io/swagger/model/DCAEService.java
index b70919f..779487c 100644
--- a/src/gen/java/io/swagger/model/DCAEService.java
+++ b/src/gen/java/io/swagger/model/DCAEService.java
@@ -1,28 +1,25 @@
-package io.swagger.model;
-
-/*
- * ============LICENSE_START==========================================
- * ===================================================================
- * Copyright (c) 2017 AT&T Intellectual Property. All rights reserved.
- * ===================================================================
+/*-
+ * ============LICENSE_START=======================================================
+ * dcae-inventory
+ * ================================================================================
+ * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============LICENSE_END============================================
- *
- * ECOMP and OpenECOMP are trademarks
- * and service marks of AT&T Intellectual Property.
- *
+ * ============LICENSE_END=========================================================
*/
+package io.swagger.model;
+
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModel;
@@ -122,7 +119,7 @@ public class DCAEService {
}
/**
* Link.title is typeName
**/
public DCAEService typeLink(Link typeLink) {
this.typeLink = typeLink;
@@ -130,7 +127,7 @@ public class DCAEService {
}
- @ApiModelProperty(value = "Link.title is typeName")
+ @ApiModelProperty(value = "Link.title is typeId")
@JsonProperty("typeLink")
public Link getTypeLink() {
return typeLink;
@@ -122,7 +119,7 @@ public class DCAEService {
}
/**
- * Link.title is typeName
+ * Link.title is typeId
**/
public DCAEService typeLink(Link typeLink) {